#!/bin/bash
#
# Copyright (C) 2014 Centro de Computacao Cientifica e Software Livre
# Departamento de Informatica - Universidade Federal do Parana - C3SL/UFPR
#
# This file is part of minicom-client-config
#
# minicom-webadmin is free software; you can redistribute it and/or
# modify it under the terms of the GNU General Public License
# as published by the Free Software Foundation; either version 2
# of the License, or (at your option) any later version.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with this program; if not, write to the Free Software
# Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301,
# USA.

# This script gets the public ssh key on the server to create a authorized_keys
# for client to help the use of many tasks on minicom-webadmin.

# Create SSH directory if necessary
DEST_USER="root"
ROOT_HOME="$(getent passwd $DEST_USER | cut -d: -f6)"
SSH_DIR="$ROOT_HOME/.ssh"
SSH_URL="http://server.telecentro.net/api/sshkey"
AUTH_KEY="authorized_keys"
TMP_SSH=$(mktemp minicom-webadmin-XXXXXXXX --tmpdir)

if [ ! -d "$SSH_DIR" ]; then
    mkdir $SSH_DIR
    echo "Created SSH directory"
fi

# Get ssh key from the server and put it in authorized_keys
if wget -q $SSH_URL -O "$TMP_SSH"; then
   
    if [ ! -f "$SSH_DIR/$AUTH_KEY" ]; then
        cat "$TMP_SSH" > "$SSH_DIR/$AUTH_KEY"
    elif ! grep -q -F -f "$TMP_SSH" "$SSH_DIR/$AUTH_KEY"; then
        cat "$TMP_SSH" >> "$SSH_DIR/$AUTH_KEY"
    fi

    # Fix authorized_keys permissions
    chmod 700 "$SSH_DIR"
    chmod 600 "$SSH_DIR/$AUTH_KEY"
    chown -R "$DEST_USER:$DEST_USER" "$SSH_DIR"

    rm -f "$TMP_SSH"

else
    echo "Warning : problems while downloading the ssh key."
fi

exit 0
